# Domain file for the model RecommendationSystem

from django.db import models
from django.utils.encoding import smart_unicode

# Class to store the data of  Book
class Book(models.Model):
    id_pk = models.AutoField(primary_key=True,null=False,blank=False)
    title = models.CharField(max_length=40,null=False,blank=False)
    published = models.DateField(auto_now=False, auto_now_add=False,null=False,blank=False)
    numberPages = models.IntegerField(null=False,blank=False)
    publisher = models.ForeignKey('Publisher', related_name='book',to_field='id_pk',null=False,blank=False)
    previous = models.OneToOneField('self', related_name='next',to_field='id_pk',null=True,blank=True)
    author = models.ManyToManyField('Author', related_name='book',null=True,blank=True)
    recommends = models.ManyToManyField('Customer', through='Recommends', related_name='book',null=True,blank=True)

    def __unicode__(self):
        return smart_unicode(self.title, encoding='utf-8', strings_only=False, errors='strict')

    class Meta:
        db_table = 'Book_rt'


# Class to store the data of  Customer
class Customer(models.Model):
    id_pk = models.AutoField(primary_key=True,null=False,blank=False)
    name = models.CharField(max_length=40,null=False,blank=False)
    address = models.CharField(max_length=40,null=False,blank=False)
    GENDER = (
        ('Man','Man'),('Woman','Woman'),
    )
    gender = models.CharField(max_length=5,choices=GENDER,null=False,blank=False)

    def __unicode__(self):
        return smart_unicode(self.name, encoding='utf-8', strings_only=False, errors='strict')

    class Meta:
        db_table = 'Customer_rt'


# Class to store the data of  Publisher
class Publisher(models.Model):
    id_pk = models.AutoField(primary_key=True,null=False,blank=False)
    name = models.CharField(max_length=40,null=False,blank=False)

    def __unicode__(self):
        return smart_unicode(self.name, encoding='utf-8', strings_only=False, errors='strict')

    class Meta:
        db_table = 'Publisher_rt'


# Class to store the data of  PremiumCustomer
class PremiumCustomer(Customer):
    membershipNumber = models.IntegerField(null=False,blank=False)
    PremiumCustomer_id_pk = models.OneToOneField('Customer',parent_link=True, related_name='PremiumCustomer',to_field='id_pk',null=False,blank=False)

    def __unicode__(self):
        return smart_unicode(self.membershipNumber, encoding='utf-8', strings_only=False, errors='strict')

    class Meta:
        db_table = 'PremiumCustomer_rt'


# Class to store the data of  Author
class Author(models.Model):
    id_pk = models.AutoField(primary_key=True,null=False,blank=False)
    name = models.CharField(max_length=40,null=False,blank=False)

    def __unicode__(self):
        return smart_unicode(self.name, encoding='utf-8', strings_only=False, errors='strict')

    class Meta:
        db_table = 'Author_rt'


# Class to store the data of  Recommends
class Recommends(models.Model):
    id_pk = models.AutoField(primary_key=True,null=False,blank=False)
    review = models.CharField(max_length=40,null=False,blank=False)
    customer = models.ForeignKey('Customer', related_name='bookfk',to_field='id_pk',null=False,blank=False)
    book = models.ForeignKey('Book', related_name='customerfk',to_field='id_pk',null=False,blank=False)

    def __unicode__(self):
        return smart_unicode(self.review, encoding='utf-8', strings_only=False, errors='strict')

    class Meta:
        db_table = 'Recommends_rt'

